function dY = FeedingReduction_AllModels_ODE(T, Y, flag, s1, K, b, v, mod)

% AUTHORS:  	Spencer Hall, sprhall@indiana.edu and Rachel Penczykowski, rpenczykowski@wustl.edu
% PROJECT: 	Penczykowski et al. 2021 Am Nat
% PURPOSE: 	This is the ordinary differential equation model simulated by "FeedingReduction_AllModels_SIM.m"
%		These equations are presented in equ. 3 of the text.

% INPUTS: 	T is time, Y is the vector of state variables (unpacked below)
% 	 	s1 is the maximal spore production coefficient
%           	K is carrying capacity
% 		b is the coefficient governing sensitivity of feeding with spores, called alpha in text
%		v is virulence; set as 0.07 by default
%       	mod is the model variant to be used

% RETURNS: 	dY, a vector of the time derivates for the four state variables.





% (0). PARAMETERS USED IN THE MODEL
% Make sure these are the same as used in the '_SIM.m' code!

e = 8.5;				% conversion efficiency 
d = 0.03;  				% background death rate of hosts
rho = 1;				% virulent effects of infection on birth rate; set at 1 assumes only feeding matters here
r = 0.8; 				% maximal growth rate of the algal resource (r_m in text)
m = 0.8; 				% loss rate of spores
u = 0.0004*10000;      		 	% per spore susceptibility
h = 0.015;              		% half saturation constant for resource-dependent spore growth
fs0 = 0.0178;            		% size-specific foraging rate of uninfecteds
L = 1.4;				% length of animals

if mod == 2             		% for ss-foraging rate of infecteds
    fq0 = fs0;          		% ... same as for uninfected if model 2 choosen
elseif mod == 4             		% for ss-foraging rate of infecteds
    fq0 = fs0;          		% ... same as for uninfected if model 2 choosen
else
    fq0 = 0.0131;        		% else a lower one
end

if mod == 2 
    b = 0;      			% if there is no feeding depression
elseif mod == 3 
    v = 0;  				% if there is no virulence on survival
end





% (1). VARIABLES USED
% This step just unpacks the state variables out of 'Y', for clarity of presentation in the next step

S = Y(1);  				% susceptible host density
Q = Y(2);  				% infected host density
Z = Y(3);  				% spore density (in the environment)
R = Y(4);  				% algal resource density (called "A" in the text)





% (2) FEEDING RATE AND SPORE YIELD
 
fs = fs0*L^2;				% feeding rate of susceptible hosts
sig = s1*R/(h+R);			% spore yield, resource-dependent - half saturation constant set above, slope is incoming
fq = fq0 * L^2 *(1 - b*sig/L^3);	% linear model - 5b - see Box 1 and Box 2
if fq < 0                   		% don't allow spore feeding rate to go negative
    fq = 0;                 		% ... instead, set to zero
end




% (2). DIFFERENTIAL EQUATIONS - equation (2) in Box (2)

dS = e*fs*R*S + rho*e*fq*R*Q - d*S - u*fs*S*Z;          % dS/dt, change in susceptible hosts
dQ = u*fs*S*Z - (d + v)*Q;                              % dI/dt, change in infected hosts
dZ = sig*(d + v)*Q - m*Z - fs*S*Z - fq*Q*Z;             % dZ/dt, change in spore density
dR = r*R*(1-R/K) - fs*R*S - fq*R*Q;                     % dR/dt, change in algal resources

dY = [dS; dQ; dZ; dR];					% package all of the time derivatives in to a vector